---
name: Question
about: Inquiry about fastnumbers

---

- [ ] I have read the [`fastnumbers` documentation](https://fastnumbers.readthedocs.io/en/master/) and the [README](https://github.com/SethMMorton/fastnumbers#fastnumbers), and my question is still not answered
